<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{ title }}</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.2/css/bootstrap.min.css" rel="stylesheet"
          integrity="sha384-xOolHFLEh07PJGoPkLv1IbcEPTNtaed2xpHsD9ESMhqIYd0nLMwNLD69Npy4HI+N" crossorigin="anonymous">
    <link rel="shortcut  icon" href="{{ url_for('static', path='/favicon.ico') }}" type="image/x-icon"/>
</head>
<body class="bg-light">
<div class="container" style="position: absolute;top: 20px;left: 0;right: 0;bottom: 50px;">

    <div class="card bg-light w-50 h-auto shadow p-3 mb-5 bg-white rounded m-auto">

        <div>
            <img class="rounded mx-auto d-block" src="{{ url_for('static', path='/logo.png') }}"
            height="170" width="170"
            />
        </div>

        <h2 class="card-title text-center">{{ hi }}</h2>
        <br>
        <form action="/form/" target="stop">
            <div class="form-group">
                <label for="git_url">用例仓库信息：</label>
                <input type="text" class="form-control" id="git_url" name="git_url"
                       placeholder="URL：ssh://ut001203@gerrit.uniontech.com:29418/autotest_deepin_music">
            </div>

            <div class="form-group">
                <div class="row">
                    <div class="col">
                        <input type="text" class="form-control" id="git_branch" name="git_branch"
                               placeholder="分支">
                    </div>
                    <div class="col">
                        <input type="text" class="form-control" id="git_user" name="git_user"
                               placeholder="git user" disabled>
                    </div>
                    <div class="col">
                        <input type="text" class="form-control" id="git_password" name="git_password"
                               placeholder="git password" disabled>
                    </div>
                </div>
            </div>
            <br>
            <div class="form-group">
                <label for="clients">测试机信息：</label>
                <input type="text" class="form-control" id="clients" name="clients"
                       placeholder="uos@10.8.13.1/uos@10.8.13.2">
            </div>
            <br>
            <div class="form-group">
                <label>用例筛选：</label>
                <div class="row">
                    <div class="col">
                        <input type="text" class="form-control" id="tags" name="tags"
                               placeholder="用例标签">
                    </div>
                    <div class="col">
                        <input type="text" class="form-control" id="keywords" name="keywords"
                               placeholder="用例关键词">
                    </div>
                </div>
            </div>
            <br>
            <div class="form-group">
                <label>测试单驱动：</label>
                <div class="row">
                    <div class="col">
                        <input type="text" class="form-control" id="task_id" name="task_id"
                               placeholder="测试单ID">
                    </div>
                    <div class="col">
                        <input type="text" class="form-control" id="fillback_user" name="fillback_user"
                               placeholder="pms user">
                    </div>
                    <div class="col">
                        <input type="text" class="form-control" id="fillback_password" name="fillback_password"
                               placeholder="pms password">
                    </div>
                </div>
            </div>


            <br>
            <div class="container d-flex justify-content-center align-items-center">
                <button type="submit" class="btn btn-primary">LetsGo</button>
            </div>

        </form>
        <iframe name="stop" style="display:none;"></iframe>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/jquery@3.5.1/dist/jquery.slim.min.js"
        integrity="sha384-DfXdz2htPH0lsSSs5nCTpuj/zy4C+OGpamoFVy38MVBnE+IbbVYUew+OrCXaRkfj"
        crossorigin="anonymous"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-7ymO4nGrkm372HoSbq1OY2DP4pEZnMiA+E0F3zPr+JQQtQ82gQ1HPY3QIVtztVua"
        crossorigin="anonymous"></script>
</body>
</html>